@@ -65,18 +65,25 @@ ImportError exception, it is silently ignored.
 import sys
 import os
 import __builtin__
+try:
+    set
+except NameError:
+    from sets import Set as set
 
 def makepath(*paths):
-    dir = os.path.abspath(os.path.join(*paths))
+    dir = os.path.join(*paths)
+    if dir == '__classpath__' and sys.platform[:4] == 'java':
+        return dir, dir
+    dir = os.path.abspath(dir)
     return dir, os.path.normcase(dir)
 
 def abs__file__():
     """Set all module' __file__ attribute to an absolute path"""
     for m in sys.modules.values():
-        try:
-            m.__file__ = os.path.abspath(m.__file__)
-        except AttributeError:
+        f = getattr(m, '__file__', None)
+        if f is None:
             continue
+        m.__file__ = os.path.abspath(f)
 
 def removeduppaths():
     """ Remove duplicate entries from sys.path along with making them
@@ -179,7 +186,7 @@ def addsitepackages(known_paths, sys_prefix=sys.prefix, exec_prefix=sys.exec_pre
         prefixes.append(os.path.join(exec_prefix, "local"))
     for prefix in prefixes:
         if prefix:
-            if sys.platform in ('os2emx', 'riscos'):
+            if sys.platform in ('os2emx', 'riscos') or sys.platform[:4] == 'java':
                 sitedirs = [os.path.join(prefix, "Lib", "site-packages")]
             elif os.sep == '/':
                 sitedirs = [os.path.join(prefix,
@@ -391,6 +398,8 @@ def virtual_install_main_packages():
         pos += 1
     if sys.platform == 'win32':
         paths = [os.path.join(sys.real_prefix, 'Lib'), os.path.join(sys.real_prefix, 'DLLs')]
+    elif sys.platform[:4] == 'java':
+        paths = [os.path.join(sys.real_prefix, 'Lib')]
     else:
         paths = [os.path.join(sys.real_prefix, 'lib', 'python'+sys.version[:3])]
         lib64_path = os.path.join(sys.real_prefix, 'lib64', 'python'+sys.version[:3])
